==> java-all-call-graph-2.0.0-sources.jar: com/adrninistrator/jacg/common/enums/ConfigKeyEnum.java <==
package com.adrninistrator.jacg.common.enums;

import com.adrninistrator.jacg.common.enums.interfaces.MainConfigInterface;

/**
 * @author adrninistrator
 * @date 2022/4/20
 * @description:
 */
public enum ConfigKeyEnum implements MainConfigInterface {
    CKE_APP_NAME("app.name", "当前应用的调用关系写入数据库里的表名后缀", String.class, true),
    CKE_CALL_GRAPH_OUTPUT_DETAIL("call.graph.output.detail", "生成调用链时的详细程度，0: 最详细，1: 详细，2: 中等，3: 最简单", String.class, true),
    CKE_THREAD_NUM("thread.num", "并发处理线程数量/数据源连接池数量", Integer.class, true),
    CKE_IGNORE_DUP_CALLEE_IN_ONE_CALLER("ignore.dup.callee.in.one.caller", "生成向下的调用链时，在一个调用方法中出现多次的被调用方法（包含方法调用业务功能数据），是否需要忽略", Boolean.class, false),
    CKE_OUTPUT_ROOT_PATH("output.root.path", "生成调用链文件的根目录路径，以\"/\"或\"\\\\\"作为分隔符，末尾是否为分隔符不影响（默认为当前目录）", String.class, false),
    CKE_OUTPUT_SUB_DIR_NAME("output.sub.dir.name", "生成调用链文件的子目录名（默认为[app.name]_[当前时间]）", String.class, false),
    CKE_DB_INSERT_BATCH_SIZE("db.insert.batch.size", "批量写入数据库时每次插入的数量", Integer.class, true),
    CKE_CHECK_JAR_FILE_UPDATED("check.jar.file.updated", "检查jar包文件是否有更新", Boolean.class, false),
    CKE_HANDLE_GET_SET_FIELD_RELATIONSHIP("handle.get.set.field.relationship", "处理通过get/set方法关联的字段关联关系", Boolean.class, false),
    ;

    // 参数key
    private final String key;
    // 参数描述
    private final String desc;
    // 参数类型
    private final Class<?> type;
    // 是否不允许为空
    private final boolean notBlank;

    ConfigKeyEnum(String key, String desc, Class<?> type, boolean notBlank) {
        this.key = key;
        this.desc = desc;
        this.type = type;
        this.notBlank = notBlank;
    }

    @Override
    public String getKey() {
        return key;
    }

    @Override
    public String getDesc() {
        return desc;
    }

    @Override
    public Class<?> getType() {
        return type;
    }

    @Override
    public boolean notBlank() {
        return notBlank;
    }

    @Override
    public String toString() {
        return key;
    }

    @Override
    public String getFileName() {
        return InputDirEnum.IDE_CONFIG.getDirName() + "/config.properties";
    }

    public static String getDescFromKey(String key) {
        for (ConfigKeyEnum configKeyEnum : ConfigKeyEnum.values()) {
            if (configKeyEnum.getKey().equals(key)) {
                return configKeyEnum.getDesc();
            }
        }
        return "";
    }
}

==> java-all-call-graph-2.0.2-sources.jar: com/adrninistrator/jacg/common/enums/ConfigKeyEnum.java <==
package com.adrninistrator.jacg.common.enums;

import com.adrninistrator.jacg.common.enums.interfaces.MainConfigInterface;

/**
 * @author adrninistrator
 * @date 2022/4/20
 * @description:
 */
public enum ConfigKeyEnum implements MainConfigInterface {
    CKE_APP_NAME("app.name", "当前应用的调用关系写入数据库里的表名后缀", String.class, true),
    CKE_CALL_GRAPH_OUTPUT_DETAIL("call.graph.output.detail", "生成调用链时的详细程度，参考 OutputDetailEnum 枚举，0: 最详细，1: 详细，2: 中等，3: 最简单", String.class, true),
    CKE_THREAD_NUM("thread.num", "并发处理线程数量/数据源连接池数量", Integer.class, true),
    CKE_IGNORE_DUP_CALLEE_IN_ONE_CALLER("ignore.dup.callee.in.one.caller", "生成向下的调用链时，在一个调用方法中出现多次的被调用方法（包含方法调用业务功能数据），是否需要忽略", Boolean.class, false),
    CKE_OUTPUT_ROOT_PATH("output.root.path", "生成调用链文件的根目录路径，以\"/\"或\"\\\\\"作为分隔符，末尾是否为分隔符不影响（默认为当前目录）", String.class, false),
    CKE_OUTPUT_DIR_FLAG("output.dir.flag", "生成调用链文件的目录名中的标志，完整目录名使用[app.name][output.dir.flag]_[当前时间]，默认为空", String.class, false),
    CKE_OUTPUT_DIR_NAME("output.dir.name", "生成调用链文件的目录名，非空时目录名使用当前值，为空时使用上一个参数说明的格式", String.class, false),
    CKE_DB_INSERT_BATCH_SIZE("db.insert.batch.size", "批量写入数据库时每次插入的数量", Integer.class, true),
    CKE_CHECK_JAR_FILE_UPDATED("check.jar.file.updated", "检查jar包文件是否有更新", Boolean.class, false),
    CKE_HANDLE_GET_SET_FIELD_RELATIONSHIP("handle.get.set.field.relationship", "处理通过get/set方法关联的字段关联关系", Boolean.class, false),
    ;

    // 参数key
    private final String key;
    // 参数描述
    private final String desc;
    // 参数类型
    private final Class<?> type;
    // 是否不允许为空
    private final boolean notBlank;

    ConfigKeyEnum(String key, String desc, Class<?> type, boolean notBlank) {
        this.key = key;
        this.desc = desc;
        this.type = type;
        this.notBlank = notBlank;
    }

    @Override
    public String getKey() {
        return key;
    }

    @Override
    public String getDesc() {
        return desc;
    }

    @Override
    public Class<?> getType() {
        return type;
    }

    @Override
    public boolean notBlank() {
        return notBlank;
    }

    @Override
    public String toString() {
        return key;
    }

    @Override
    public String getFileName() {
        return InputDirEnum.IDE_CONFIG.getDirName() + "/config.properties";
    }

    public static String getDescFromKey(String key) {
        for (ConfigKeyEnum configKeyEnum : ConfigKeyEnum.values()) {
            if (configKeyEnum.getKey().equals(key)) {
                return configKeyEnum.getDesc();
            }
        }
        return "";
    }
}
